@@ -53,7 +53,7 @@
 #ifndef QDBUS_SYMBOLS_P_H
 #define QDBUS_SYMBOLS_P_H
 
-#include <QtCore/qglobal.h>
+#include <QtDBus/private/qtdbusglobal_p.h>
 
 #ifndef QT_NO_DBUS
 
@@ -63,6 +63,10 @@
 #  include "dbus_minimal_p.h"
 #endif
 
+#ifdef interface
+#  undef interface
+#endif
+
 QT_BEGIN_NAMESPACE
 
 #if !defined QT_LINKED_LIBDBUS
